import os
from django.conf import settings
from django.test import TestCase
from jsanctions.eu_combined import import_eu_combined_sanctions_list
from jsanctions.models import SanctionEntity, SanctionsListFile


class Tests(TestCase):
    def test_eu_combined_sanctions_list_import(self):
        filename = os.path.join(settings.BASE_DIR, "data/eu-combined/2021-03-05.xml")
        source = SanctionsListFile.objects.create_from_filename(filename)
        assert isinstance(source, SanctionsListFile)
        import_eu_combined_sanctions_list(source, verbose=False)
        self.assertEqual(SanctionEntity.objects.all().count(), 2269)



import logging
import os
from urllib.request import urlopen
from django.core.files import File
from django.core.files.base import ContentFile
from django.core.validators import FileExtensionValidator
from django.db import models
from django.utils.timezone import now
from django.utils.translation import gettext_lazy as _
from jutil.format import is_media_full_path, strip_media_root, get_media_full_path
from jutil.modelfields import SafeCharField, SafeTextField

logger = logging.getLogger(__name__)


REMARK_BRIEF_LENGTH = 128
DEFAULT_DESCRIPTION_TYPE = {"blank": True, "max_length": 512, "default": ""}
DEFAULT_REMARK_TYPE = {
    "verbose_name": _("remark"),
    "null": True,
    "default": None,
    "blank": True,
    "on_delete": models.SET_NULL,
}
DEFAULT_CODE_TYPE = {"blank": True, "max_length": 32, "default": ""}
DEFAULT_DATE_TYPE = {"blank": True, "null": True, "default": None}
LANGUAGE_CODE_TYPE = {"blank": True, "default": "", "max_length": 5}
COUNTRY_CODE_TYPE = {"blank": True, "default": "", "max_length": 3}
DEFAULT_BOOLEAN_TYPE = {"blank": True, "default": None, "null": True}
DEFAULT_INT_TYPE = {"blank": True, "default": None, "null": True}
REGULATION_SUMMARY_TYPE = {
    "verbose_name": _("regulation summary"),
    "blank": True,
    "default": None,
    "null": True,
    "on_delete": models.PROTECT,
}


class SanctionsListFileManager(models.Manager):
    def create_from_filename(self, filename: str, **kwargs):
        full_path = os.path.realpath(filename)
        file = self.create(**kwargs)
        assert isinstance(file, SanctionsListFile)
        if is_media_full_path(full_path):
            file.file.name = strip_media_root(full_path)
            file.save()
        else:
            with open(full_path, "rb") as fp:
                plain_filename = os.path.basename(filename)
                file.file.save(plain_filename, File(fp))
        return file

    def create_from_url(self, url: str, filename: str, **kwargs):
        response = urlopen(url)
        body = response.read()
        plain_filename = os.path.basename(filename)
        file = self.create(**kwargs)
        file.file.save(plain_filename, ContentFile(body))
        return file


class SanctionListObject(models.Model):
    pass


class SanctionsListFile(SanctionListObject):
    objects = SanctionsListFileManager()  # type: ignore
    created = models.DateTimeField(verbose_name=_("created"), default=now, blank=True, editable=False, db_index=True)
    imported = models.DateTimeField(
        verbose_name=_("imported"), default=None, null=True, blank=True, editable=False, db_index=True
    )
    generation_date = models.DateField(
        verbose_name=_("generation date"), default=None, blank=True, null=True, editable=False, db_index=True
    )
    file = models.FileField(verbose_name=_("file"), upload_to="uploads", validators=[FileExtensionValidator(["xml"])])
    list_type = SafeCharField(verbose_name=_("list type"), max_length=128, db_index=True)
    global_file_id = SafeCharField(verbose_name=_("global file id"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore

    class Meta:
        verbose_name = _("sanction list")
        verbose_name_plural = _("sanction lists")

    def __str__(self):
        return "{}".format(os.path.basename(self.file.name))

    @property
    def full_path(self) -> str:
        return get_media_full_path(self.file.name)


class Remark(models.Model):
    container = models.ForeignKey(SanctionListObject, on_delete=models.CASCADE)
    text = SafeTextField(verbose_name=_("text"), blank=True)

    class Meta:
        verbose_name = _("remark")
        verbose_name_plural = _("remarks")

    def __str__(self) -> str:
        return str(self.text)

    @property
    def text_brief(self) -> str:
        return self.text if len(self.text) < REMARK_BRIEF_LENGTH else self.text[:REMARK_BRIEF_LENGTH] + "..."


class SubjectType(SanctionListObject):
    code = SafeCharField(verbose_name=_("code"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    classification_code = SafeCharField(verbose_name=_("classification code"), **DEFAULT_CODE_TYPE)  # type: ignore

    class Meta:
        verbose_name = _("subject type")
        verbose_name_plural = _("subject types")

    def __str__(self) -> str:
        return str(self.code)


class Regulation(SanctionListObject):
    sanction = models.ForeignKey("SanctionEntity", verbose_name=_("sanction entity"), on_delete=models.CASCADE)
    regulation_type = SafeCharField(verbose_name=_("regulation type"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    organisation_type = SafeCharField(verbose_name=_("organization type"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    publication_date = models.DateField(verbose_name=_("publication date"), **DEFAULT_DATE_TYPE)  # type: ignore
    publication_url = models.URLField(verbose_name=_("url"), blank=True, default="")
    entry_into_force_date = models.DateField(verbose_name=_("entry into force date"), **DEFAULT_DATE_TYPE)  # type: ignore
    number_title = SafeCharField(verbose_name=_("number title"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    programme = SafeCharField(verbose_name=_("programmer"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)

    class Meta:
        verbose_name = _("regulation")
        verbose_name_plural = _("regulations")


class RegulationSummary(SanctionListObject):
    regulation_type = SafeCharField(verbose_name=_("regulation type"), **DEFAULT_CODE_TYPE)  # type: ignore
    number_title = SafeCharField(verbose_name=_("number title"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    publication_date = models.DateField(verbose_name=_("publication date"), **DEFAULT_DATE_TYPE)  # type: ignore
    publication_url = models.URLField(verbose_name=_("url"), blank=True, default="")

    class Meta:
        verbose_name = _("regulation summary")
        verbose_name_plural = _("regulation summaries")

    def __str__(self) -> str:
        return "{} {}".format(self.regulation_type, self.number_title)


class NameAlias(SanctionListObject):
    sanction = models.ForeignKey("SanctionEntity", verbose_name=_("sanction entity"), on_delete=models.CASCADE)
    first_name = SafeCharField(verbose_name=_("first name"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    middle_name = SafeCharField(verbose_name=_("middle name"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    last_name = SafeCharField(verbose_name=_("last name"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    whole_name = SafeCharField(verbose_name=_("whole name"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    name_language = SafeCharField(verbose_name=_("name language"), **LANGUAGE_CODE_TYPE)  # type: ignore
    function = SafeCharField(verbose_name=_("function"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    title = SafeCharField(verbose_name=_("title"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    regulation_language = SafeCharField(verbose_name=_("regulation language"), **LANGUAGE_CODE_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)
    regulation_summary = models.ForeignKey(RegulationSummary, **REGULATION_SUMMARY_TYPE)  # type: ignore

    class Meta:
        verbose_name = _("name alias")
        verbose_name_plural = _("name aliases")

    def __str__(self) -> str:
        return str(self.whole_name)

    def clean(self):
        if len(self.function) > 256:
            self.function = self.function[:256]


class Identification(SanctionListObject):
    sanction = models.ForeignKey("SanctionEntity", verbose_name=_("sanction entity"), on_delete=models.CASCADE)
    diplomatic = models.BooleanField(verbose_name=_("diplomatic"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    known_expired = models.BooleanField(verbose_name=_("known expired"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    known_false = models.BooleanField(verbose_name=_("known false"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    reported_lost = models.BooleanField(verbose_name=_("reported lost"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    revoked_by_issuer = models.BooleanField(verbose_name=_("revoked by issuer"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    issued_by = SafeCharField(verbose_name=_("issued by"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    latin_number = SafeCharField(verbose_name=_("latin number"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    name_on_document = SafeCharField(verbose_name=_("name on document"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    number = SafeCharField(verbose_name=_("number"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    region = SafeCharField(verbose_name=_("region"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    country_iso2_code = SafeCharField(verbose_name=_("issued by"), **COUNTRY_CODE_TYPE)  # type: ignore
    country_description = SafeCharField(verbose_name=_("country description"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    identification_type_code = SafeCharField(verbose_name=_("identification type code"), **DEFAULT_CODE_TYPE)  # type: ignore
    identification_type_description = SafeCharField(verbose_name=_("identification type code"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    regulation_language = SafeCharField(verbose_name=_("regional language"), **LANGUAGE_CODE_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)
    regulation_summary = models.ForeignKey(RegulationSummary, **REGULATION_SUMMARY_TYPE)  # type: ignore

    class Meta:
        verbose_name = _("identification")
        verbose_name_plural = _("identifications")


class BirthDate(SanctionListObject):
    sanction = models.ForeignKey("SanctionEntity", verbose_name=_("sanction entity"), on_delete=models.CASCADE)
    circa = models.BooleanField(verbose_name=_("circa"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    calendar_type = SafeCharField(verbose_name=_("calendar type"), **DEFAULT_CODE_TYPE)  # type: ignore
    city = SafeCharField(verbose_name=_("city"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    zip_code = SafeCharField(verbose_name=_("zip code"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    birth_date = models.DateField(verbose_name=_("birth date"), **DEFAULT_DATE_TYPE)  # type: ignore
    day_of_month = models.IntegerField(verbose_name=_("day of month"), **DEFAULT_INT_TYPE)  # type: ignore
    month_of_year = models.IntegerField(verbose_name=_("month of year"), **DEFAULT_INT_TYPE)  # type: ignore
    year = models.IntegerField(verbose_name=_("year"), **DEFAULT_INT_TYPE)  # type: ignore
    region = SafeCharField(verbose_name=_("region"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    place = SafeCharField(verbose_name=_("place"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    country_iso2_code = SafeCharField(verbose_name=_("country"), **COUNTRY_CODE_TYPE)  # type: ignore
    country_description = SafeCharField(verbose_name=_("country description"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    regulation_language = SafeCharField(verbose_name=_("regional language"), **LANGUAGE_CODE_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)

    class Meta:
        verbose_name = _("birth date")
        verbose_name_plural = _("birth dates")


class Citizenship(SanctionListObject):
    sanction = models.ForeignKey("SanctionEntity", verbose_name=_("sanction entity"), on_delete=models.CASCADE)
    region = SafeCharField(verbose_name=_("region"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    country_iso2_code = SafeCharField(verbose_name=_("country"), **COUNTRY_CODE_TYPE)  # type: ignore
    country_description = SafeCharField(verbose_name=_("country description"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    regulation_language = SafeCharField(verbose_name=_("regional language"), **LANGUAGE_CODE_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)
    regulation_summary = models.ForeignKey(RegulationSummary, **REGULATION_SUMMARY_TYPE)  # type: ignore

    class Meta:
        verbose_name = _("citizenship")
        verbose_name_plural = _("citizenships")


class Address(SanctionListObject):
    sanction = models.ForeignKey("SanctionEntity", verbose_name=_("sanction entity"), on_delete=models.CASCADE)
    city = SafeCharField(verbose_name=_("city"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    street = SafeCharField(verbose_name=_("street"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    po_box = SafeCharField(verbose_name=_("p.o. box"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    zip_code = SafeCharField(verbose_name=_("zip code"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    as_at_listing_time = models.BooleanField(_("as at listing time"), **DEFAULT_BOOLEAN_TYPE)  # type: ignore
    place = SafeCharField(verbose_name=_("place"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    region = SafeCharField(verbose_name=_("region"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    country_iso2_code = SafeCharField(verbose_name=_("country"), **COUNTRY_CODE_TYPE)  # type: ignore
    country_description = SafeCharField(verbose_name=_("country description"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    regulation_language = SafeCharField(verbose_name=_("regional language"), **LANGUAGE_CODE_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)
    regulation_summary = models.ForeignKey(RegulationSummary, **REGULATION_SUMMARY_TYPE)  # type: ignore

    class Meta:
        verbose_name = _("address")
        verbose_name_plural = _("addresses")


class SanctionEntity(SanctionListObject):
    source = models.ForeignKey(SanctionsListFile, verbose_name=_("source"), on_delete=models.CASCADE)
    designation_details = SafeCharField(verbose_name=_("designation details"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    united_nation_id = SafeCharField(verbose_name=_("United Nation identifier"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    eu_reference_number = SafeCharField(verbose_name=_("EU reference number"), **DEFAULT_DESCRIPTION_TYPE)  # type: ignore
    logical_id = models.BigIntegerField(verbose_name=_("logical id"), blank=True, null=True, default=None)
    subject_type = models.ForeignKey(
        SubjectType, verbose_name=_("subject type"), on_delete=models.PROTECT, null=True, default=None, blank=True
    )

    class Meta:
        verbose_name = _("sanction entity")
        verbose_name_plural = _("sanction entities")



import logging
import os
from typing import Optional

from django.core.management.base import CommandParser
from django.utils.timezone import now
from jsanctions.eu_combined import import_eu_combined_sanctions_list, EU_LIST_TYPE
from jutil.command import SafeCommand
from jsanctions.models import SanctionsListFile

logger = logging.getLogger(__name__)


class Command(SafeCommand):
    help = "Imports EU combined sanction lists"

    def add_arguments(self, parser: CommandParser):
        parser.add_argument("--url", type=str)
        parser.add_argument("--file", type=str)
        parser.add_argument("--delete-old", action="store_true")
        parser.add_argument("--source", type=int)
        parser.add_argument("--new", action="store_true")
        parser.add_argument("--verbose", action="store_true")

    def do(self, *args, **options):  # pylint: disable=too-many-branches
        verbose = options["verbose"]
        source: Optional[SanctionsListFile] = None
        if options["url"]:
            filename = options["file"] if options["file"] else "EU-combined-{}.xml".format(now().date().isoformat())
            source = SanctionsListFile.objects.create_from_url(options["url"], filename, list_type=EU_LIST_TYPE)
        elif options["file"]:
            source = SanctionsListFile.objects.create_from_filename(options["file"], list_type=EU_LIST_TYPE)
        elif options["source"]:
            source = SanctionsListFile.objects.get(id=options["source"])
        elif options["new"]:
            source = SanctionsListFile.objects.filter(imported=None).order_by("id").first()
        if not source:
            print("Nothing to import")
            return

        assert isinstance(source, SanctionsListFile)
        import_eu_combined_sanctions_list(source, verbose=verbose)

        if options["delete_old"]:
            for e in SanctionsListFile.objects.all().filters(list_type=EU_LIST_TYPE).exclude(id=source.id):
                assert isinstance(e, SanctionsListFile)
                logger.info("Deleting %s", e)
                if os.path.isfile(e.full_path):
                    os.unlink(e.full_path)
                e.delete()
                logger.info("%s deleted", e)



from typing import List, Dict
from jsanctions.helpers import dict_filter_attributes
from jutil.parse import parse_datetime
from jutil.xml import xml_to_dict
import logging
import os
from typing import Any
from django.db import transaction
from django.utils.timezone import now
from jutil.admin import admin_log
from jsanctions.models import (
    SanctionsListFile,
    SanctionEntity,
    RegulationSummary,
    BirthDate,
    Identification,
    Remark,
    Address,
    Citizenship,
    NameAlias,
    Regulation,
    SubjectType,
)
from jutil.format import camel_case_to_underscore

logger = logging.getLogger(__name__)

EU_LIST_TYPE = "EU-Combined"

EU_XML_ARRAY_TAGS = [
    "sanctionEntity",
    "nameAlias",
    "identification",
    "address",
    "birthdate",
    "citizenship",
    "regulation",
    "remark",
]

EU_XML_INT_TAGS: List[str] = []

EU_XML_DATE_ATTRIBUTES = [
    "@birthdate",
]


def eu_combined_sanction_list_xml_attr_filter(k: str, v: Any):
    if k.endswith("Date") or k in EU_XML_DATE_ATTRIBUTES:
        return parse_datetime(v).date()
    if k == "@logicalId":
        return int(v)
    if v == "false":
        return False
    if v == "true":
        return True
    return v


def load_eu_combined_sanction_list_as_dict(filename: str) -> Dict[str, Any]:
    with open(filename, "rb") as fp:
        data: Dict[str, Any] = xml_to_dict(fp.read(), array_tags=EU_XML_ARRAY_TAGS, int_tags=EU_XML_INT_TAGS)
        data = dict_filter_attributes(data, eu_combined_sanction_list_xml_attr_filter)
    return data


def eu_set_object_attr(obj, k: str, v, max_length: int = 512):
    if v and isinstance(v, str) and len(v) > max_length:
        logger.warning("'%s' truncated to [%s]: '%s...'", k, max_length, v[:64])
        v = v[: max_length - 3] + "..."
    setattr(obj, k, v)


def eu_set_simple_members(  # noqa
    obj, data: dict, commit: bool = True, verbose: bool = True, padding: int = 0, **kwargs
):
    class_map = {
        "regulationSummary": RegulationSummary,
        "subjectType": SubjectType,
    }
    array_class_map = {
        "birthdate": BirthDate,
        "identification": Identification,
        "address": Address,
        "citizenship": Citizenship,
        "nameAlias": NameAlias,
        "regulation": Regulation,
    }

    padding_str = " " * padding
    obj.save()
    obj2: Any
    for k0, v0 in data.items():
        if k0[0] == "@":
            k = camel_case_to_underscore(k0[1:])
            if k == "birthdate":
                k = "birth_date"  # special case because class name same as attribute
            if hasattr(obj, k):
                eu_set_object_attr(obj, k, v0)
                if verbose:
                    logger.info("%s%s: %s = %s", padding_str, obj, k, v0)
        elif k0 in class_map:
            k = camel_case_to_underscore(k0)
            if hasattr(obj, k):
                if k == "subject_type":
                    obj2 = SubjectType.objects.get_or_create(
                        code=v0.get("@code", ""), classification_code=v0.get("@classificationCode", "")
                    )[0]
                elif k == "regulation_summary":
                    obj2 = RegulationSummary.objects.get_or_create(
                        regulation_type=v0.get("@regulationType", ""),
                        publication_date=v0.get("@publicationDate", None),
                        publication_url=v0.get("@publicationUrl", ""),
                        number_title=v0.get("@numberTitle", ""),
                    )[0]
                else:
                    obj2 = class_map[k0]()
                    kwargs2 = {}
                    kwargs2[k] = obj2
                    for k2, v2 in kwargs.items():
                        eu_set_object_attr(obj2, k2, v2)
                        kwargs2[k2] = v2

                    eu_set_simple_members(obj2, v0, verbose=verbose, padding=padding + 4, **kwargs2)

                eu_set_object_attr(obj, k, obj2)
        elif k0 in array_class_map:
            k = camel_case_to_underscore(k0)
            cls = array_class_map[k0]
            for v0_data in v0:
                obj2 = cls()
                kwargs2 = {}
                kwargs2[k] = obj2
                for k2, v2 in kwargs.items():
                    eu_set_object_attr(obj2, k2, v2)
                    kwargs2[k2] = v2
                obj2.clean()
                obj2.save()
                eu_set_simple_members(obj2, v0_data, verbose=verbose, padding=padding + 4, **kwargs2)
        elif k0 == "remark":
            for v0_str in v0:
                Remark.objects.create(text=v0_str, container=obj)

    if commit:
        if verbose:
            logger.info("Saving %s", obj)
        obj.clean()
        obj.save()


def import_eu_combined_sanctions_list(source: SanctionsListFile, verbose: bool = False):
    data = load_eu_combined_sanction_list_as_dict(source.full_path)
    eu_set_simple_members(source, data, verbose=verbose)
    entities_list = data.get("sanctionEntity", [])
    logger.info("Importing %s sanction entities from %s", len(entities_list), os.path.basename(source.file.name))
    t0 = now()
    for se_data in entities_list:
        assert isinstance(se_data, dict)
        if verbose:
            logger.info("  sanctionEntity")
        with transaction.atomic():
            se = SanctionEntity.objects.create(source=source)
            eu_set_simple_members(se, se_data, verbose=verbose, padding=4, sanction=se)
    source.imported = now()
    source.save()
    msg = "Imported {} sanction entities from {} in {}".format(
        len(entities_list), os.path.basename(source.file.name), source.imported - t0
    )
    logger.info(msg)
    admin_log([source], msg)



# Generated by Django 3.0.7 on 2021-03-05 15:55

from django.db import migrations
import jutil.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ("jsanctions", "0004_auto_20200629_0350"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="eucombinedsanctionslist",
            name="global_file_id",
        ),
        migrations.AddField(
            model_name="sanctionslistfile",
            name="global_file_id",
            field=jutil.modelfields.SafeCharField(
                blank=True, default="", max_length=512, verbose_name="global file id"
            ),
        ),
    ]



# Generated by Django 2.2.5 on 2020-02-26 03:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jsanctions", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="address",
            name="city",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="city"),
        ),
        migrations.AlterField(
            model_name="address",
            name="country_description",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="country description"),
        ),
        migrations.AlterField(
            model_name="address",
            name="place",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="place"),
        ),
        migrations.AlterField(
            model_name="address",
            name="po_box",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="p.o. box"),
        ),
        migrations.AlterField(
            model_name="address",
            name="region",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="region"),
        ),
        migrations.AlterField(
            model_name="address",
            name="street",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="street"),
        ),
        migrations.AlterField(
            model_name="address",
            name="zip_code",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="zip code"),
        ),
        migrations.AlterField(
            model_name="birthdate",
            name="city",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="city"),
        ),
        migrations.AlterField(
            model_name="birthdate",
            name="country_description",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="country description"),
        ),
        migrations.AlterField(
            model_name="birthdate",
            name="place",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="place"),
        ),
        migrations.AlterField(
            model_name="birthdate",
            name="region",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="region"),
        ),
        migrations.AlterField(
            model_name="birthdate",
            name="zip_code",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="zip code"),
        ),
        migrations.AlterField(
            model_name="citizenship",
            name="country_description",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="country description"),
        ),
        migrations.AlterField(
            model_name="citizenship",
            name="region",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="region"),
        ),
        migrations.AlterField(
            model_name="eucombinedsanctionslist",
            name="global_file_id",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="global file id"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="country_description",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="country description"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="identification_type_description",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="identification type code"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="issued_by",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="issued by"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="latin_number",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="latin number"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="name_on_document",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="name on document"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="number",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="number"),
        ),
        migrations.AlterField(
            model_name="identification",
            name="region",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="region"),
        ),
        migrations.AlterField(
            model_name="namealias",
            name="first_name",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="first name"),
        ),
        migrations.AlterField(
            model_name="namealias",
            name="function",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="function"),
        ),
        migrations.AlterField(
            model_name="namealias",
            name="last_name",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="last name"),
        ),
        migrations.AlterField(
            model_name="namealias",
            name="middle_name",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="middle name"),
        ),
        migrations.AlterField(
            model_name="namealias",
            name="title",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="title"),
        ),
        migrations.AlterField(
            model_name="namealias",
            name="whole_name",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="whole name"),
        ),
        migrations.AlterField(
            model_name="regulation",
            name="number_title",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="number title"),
        ),
        migrations.AlterField(
            model_name="regulation",
            name="organisation_type",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="organization type"),
        ),
        migrations.AlterField(
            model_name="regulation",
            name="programme",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="programmer"),
        ),
        migrations.AlterField(
            model_name="regulation",
            name="regulation_type",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="regulation type"),
        ),
        migrations.AlterField(
            model_name="regulationsummary",
            name="number_title",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="number title"),
        ),
        migrations.AlterField(
            model_name="sanctionentity",
            name="designation_details",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="designation details"),
        ),
        migrations.AlterField(
            model_name="sanctionentity",
            name="eu_reference_number",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="EU reference number"),
        ),
        migrations.AlterField(
            model_name="sanctionentity",
            name="united_nation_id",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="United Nation identifier"),
        ),
        migrations.AlterField(
            model_name="subjecttype",
            name="code",
            field=models.CharField(blank=True, default="", max_length=512, verbose_name="code"),
        ),
    ]



# -*- coding: utf-8 -*-
from distutils.core import setup
from setuptools import find_packages  # type: ignore


def parse_requirements(filename, session=False):
    """ load requirements from a pip requirements file """
    lineiter = (line.strip() for line in open(filename))
    return [line for line in lineiter if line and not line.startswith("#")]


install_requires = parse_requirements("requirements.txt", session=False)

setup(
    name="django-jsanctions",
    version="3.5.1",
    author=u"Jani Kajala",
    author_email="kajala@gmail.com",
    packages=find_packages(exclude=["project", "venv"]),
    include_package_data=True,
    url="https://github.com/kajala/django-jsanctions",
    license="MIT licence, see LICENCE.txt",
    description="Parses and imports EU combined sanction lists for Django projects",
    long_description=open("README.md").read(),
    zip_safe=False,
    install_requires=install_requires,
)
